]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - common.c
Fixups for Solaris port.
[xonotic/darkplaces.git] / common.c
index 584cfd790b577c0b5b6f4cab23a8056d11ac8d8c..86d448b0b1ba9b50e4553557613422618ee56bf6 100644 (file)
--- a/common.c
+++ b/common.c
@@ -961,10 +961,10 @@ static const gamemode_info_t gamemode_info [] =
 // COMMANDLINEOPTION: Game: -prydon runs the topdown point and click action-RPG Prydon Gate
 { "prydon",                    "-prydon",              "PrydonGate",                   "id1",          "prydon",               "prydon",               "darkplaces"},
 // GAME_NETHERWORLD
-// COMMANDLINEOPTION: Game: -netherworld runs the game Netherworld: Dark Masters
-{ "netherworld",       "-netherworld", "Dark Masters",                 "id1",          "netherworld",  "nw",                   "darkplaces"},
+// COMMANDLINEOPTION: Game: -netherworld runs the game Netherworld: Dark Master
+{ "netherworld",       "-netherworld", "Netherworld: Dark Master",     "id1",          "netherworld",  "nw",                   "darkplaces"},
 // GAME_THEHUNTED
-// COMMANDLINEOPTION: Game: -netherworld runs the game The Hunted
+// COMMANDLINEOPTION: Game: -thehunted runs the game The Hunted
 { "thehunted",         "-thehunted",   "The Hunted",                   "thdata",       NULL,                   "th",                   "thehunted"},
 };